#
# spec file for package libmpdclient
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_name 2
Name:           libmpdclient
Version:        2.18
Release:        3.2
Summary:        Library for interfacing the Music Player Daemon
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://musicpd.org/libs/libmpdclient
Source0:        https://musicpd.org/download/%{name}/2/%{name}-%{version}.tar.xz
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig

%description
A stable, documented, asynchronous API library for interfacing MPD (Music Player Daemon)
in the C, C++ & Objective C languages.

%package -n %{name}%{so_name}
Summary:        Library for interfacing the Music Player Daemon
Group:          System/Libraries

%description -n %{name}%{so_name}
A stable, documented, asynchronous API library for interfacing MPD (Music Player Daemon).

%package devel
Summary:        Development files for libmpdclient
Group:          Development/Languages/C and C++
Requires:       %{name}%{so_name} = %{version}

%description devel
This package contains the development files, e.g. header-files, for
libmpdclient - a stable, documented and asynchronous API library for
MPD (Music Player Daemon).

%prep
%setup -q

%build
%meson -D documentation=false
%meson_build

%install
%meson_install
rm -r %{buildroot}%{_datadir}/doc

%post   -n %{name}%{so_name} -p /sbin/ldconfig
%postun -n %{name}%{so_name} -p /sbin/ldconfig

%files -n %{name}%{so_name}
%license COPYING
%doc AUTHORS
%{_libdir}/%{name}.so.*

%files devel
%doc NEWS
%{_includedir}/mpd
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/vala

%changelog
* Mon Jan 27 2020 ilya@ilya.pp.ua
- Update to 2.18
  * https://raw.githubusercontent.com/MusicPlayerDaemon/libmpdclient/v2.18/NEWS
  * more out-of-memory checks
  * partition: add mpd_recv_partition()
  * support MPD protocol 0.21
  * "oneshot" single state
  * support MPD protocol 0.22
  * status: add mpd_status_get_partition()
  * commands "delpartition", "moveoutput"
* Thu Dec  5 2019 ilya@ilya.pp.ua
- Update to 2.17
  * https://raw.githubusercontent.com/MusicPlayerDaemon/libmpdclient/v2.17/NEWS
  * search: add mpd_search_add_db_songs_to_playlist()
  * idle: support event "partition"
  * support MPD protocol 0.19 - "listneighbors"
  * support MPD protocol 0.22 - "getfingerprint"
  * support tags "MPD_TAG_LABEL", "MPD_TAG_MUSICBRAINZ_WORKID",
    "Grouping", "Work", "Conductor"
  * support MPD partitions
  * mpd_async_set_keepalive() returns bool
  * mpd_connection_set_keepalive() returns bool
* Thu Nov  8 2018 aloisio@gmx.com
- Update to version 2.16
  * support MPD protocol 0.19
    + "mount", "unmount", "listmounts"
  * support MPD protocol 0.17
    + "load" with range
  * add mpd_output_get_attribute()
  * use UINX_MAX instead of `(unsigned)-1` to avoid undefined
    behavior
* Thu Oct  4 2018 tchvatal@suse.com
- Update to 2.15:
  * support MPD protocol 0.17
  * Various compiler warning fixes
- Use meson macros
* Thu Jul 27 2017 olaf@aepfle.de
- Update to 2.13
  * fix build with meson > 0.38.1
  * fix connect error "Operation now in progress"
  * support MPD protocol 0.21
  - support tag "OriginalDate"
  - command "tagtypes" plus "disable", "enable", "clear"
  * support MPD protocol 0.20
  - support "plchanges" and "plchangesposid" with range
  * support MPD protocol 0.19
  - commands "addtagid", "cleartagid"
  - command "listfiles"
  - grouping for "list" and "count"
  - tag "AlbumSort"
  - "seekid" with float time
  * use relative #include paths to avoid clashes with other libmpdclient copies
  * build with Meson instead of autotools
* Mon Apr 17 2017 olaf@aepfle.de
- Update to 2.11
  * fix heap corruption with mpd_connection_new_async()
  * add space before "window" search argument
  * detect getaddrinfo() at configure time
  * add support for ArtistSort and AlbumArtistSort tags
  * support MPD protocol 0.21
  - audio format specifications "dsd64" etc.
* Sun Nov  1 2015 rpm@fthiessen.de
- Updated package to 2.10
  * support abstract sockets with "@" prefix
  * support tag "MUSICBRAINZ_RELEASETRACKID"
  * add TCP keepalive internal and external APIs
  * support MPD protocol 0.19 and 0.20
* Sat Oct 31 2015 rpm@fthiessen.de
- Initial version 2.9
